<html>
    <body>

    <script src="jquery-3.6.1.min.js"></script>
    <script src="sweetalert2.all.min.js"></script> 

<?php
    if(isset($_SESSION['upload_status']))
    {
        ?>
        <div class = "alert alert-warning alert-dismissible fade show" role="alert">
        <script>
            swal({
                title: "<?php echo $_SESSION['upload_status']; ?>",
                button: "ok ",
            });
        </script>
        </div>
        <?php
            unset($_SESSION['upload_status']);
    }

?>


</body>
</html>
