<?php
session_start();
if(!isset($_SESSION['user']) || empty($_SESSION['user'])) {
    header("location: login.php"); exit();
}
?>
<html xmlns="http://www.w3.org/1999/xhtml">
    <head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8">

	<meta http-equiv="cache-control" content="no-cache">
	<meta http-equiv="pragma" content="no-cache">
	<meta http-equiv="expires" content="0">
	<title>Cardinal 825 - Programmable Digital Weight Indicator</title>
	<link href="main.css" rel="stylesheet" type="text/css">
	<link href="filemgr.css" rel="stylesheet" type="text/css">
    <link href="cardinal.css" rel="stylesheet" type="text/css">

	<meta name="viewport" content="width=device-width">

</head>
<body>

<div class="container">

    <div class="row">
        <div class="col-sm-4" id ="main_tab">
            <img src="Cardinal_logo.png" width="60%" background-size="100%">
        </div>

        <br><br><br><br>
		<div class="col-sm-8" id ="main_tab">
				<ul class="nav nav-pills ">
					<li class="nav-item">
                        <a href="index.php" class="nav-link active"
						data-toggle="pill" data-target="#tabone">home</a>
                    </li>
					<li class="nav-item bg-light"><a href="tinyfilemanager.php" class="nav-link"
						data-toggle="pill" data-target="#tabtwo">files</a>
                    </li>
					<li class="nav-item bg-light"><a class="nav-link"
                        href="diagnostics.php" data-target="#tabthree" data-toggle="pill">diagnostics</a>
                    </li>
                    <li class="nav-item bg-light"><a class="nav-link"
                        href="admin.php" data-target="#tabfour" data-toggle="pill">admin</a>
                    </li>
                    <li class="nav-item bg-light"><a class="nav-link"
                        href = "reports.php" data-target="#tabfive" data-toggle="pill">reports</a>
                    </li>
                </ul>
		</div>
    </div>
</div>

<div class="container">
    
    <div class="row">
        <div class= "img">
        <img src="825_Banner.jpg" style="max-width: 110%; height:130%">
        <prim2 >825 Webpage Management</prim2>
        <second >The 825 web server allows you to manage files and<br/>view diagnostics information.</second>
    </div>
</div>
</div>
    
	<br><br><br><br>
    <br><br><br><br>
	<div id="footer">
		<div class="right">
		</div>
		<p>
			<a href="https://cardinalscale.com//">Cardinal Technical Support</a><br>
			© Copyright 2008 <a href="https://cardinalscale.com/product/">Cardinal Scale MFG</a> · All Rights Reserved
		</p>
	</div>
    
    </body>
</html>
